diff options
| author | KunoiSayami <[email protected]> | 2023-07-02 21:53:47 +0800 |
|---|---|---|
| committer | KunoiSayami <[email protected]> | 2023-07-02 21:53:47 +0800 |
| commit | c71e687de86691c0149804ef10721ac9c230ab9e (patch) | |
| tree | c5edef26ed08eeea4c4479016faea2dbcca7430c /expt_0516.cu | |
| parent | 0b09bc40d295e7b383f2e5c8ddba255f0ac680ca (diff) | |
refactor: Change basic function name
Signed-off-by: KunoiSayami <[email protected]>
Diffstat (limited to 'expt_0516.cu')
| -rw-r--r-- | expt_0516.cu | 7 |
1 files changed, 3 insertions, 4 deletions
diff --git a/expt_0516.cu b/expt_0516.cu index 1954380..483278e 100644 --- a/expt_0516.cu +++ b/expt_0516.cu @@ -67,8 +67,7 @@ __global__ void kernel(const size_t test_length) { if (tid >= test_length) return; // printf("%d\n", tid); - custom_sort.sample_cdf_custom_version(cudaSampleItem, - cudaPopulationItem[tid]); + custom_sort.cdf(cudaSampleItem, cudaPopulationItem[tid]); // cdf_result[index] = true; } } @@ -82,8 +81,8 @@ __global__ void kernel2(const size_t test_length) { if (tid >= test_length) return; - FactorySort::sample_cdf(cudaNormalSampleItem, cuda_sample_length, - cudaPopulationItem[tid]); + FactorySort::cdf(cudaNormalSampleItem, cuda_sample_length, + cudaPopulationItem[tid]); // cdf_result[index] = true; } } |
